@@ -29,6 +29,7 @@
 #define _(string) gettext(string)
 
 #include "exc.h"
+#include "dbg.h"
 #include "str.h"
 #include "msg.h"
 #include "timer.h"
@@ -54,8 +55,10 @@ float player::normalize_pos(int64_t pos) const
 {
     double pos_min = _start_pos + global_dispatch->get_media_input()->initial_skip();
     double pos_max = pos_min + global_dispatch->get_media_input()->duration();
-    double npos = (pos_max > pos_min ? (static_cast<double>(pos) - pos_min) / (pos_max - pos_min) : 0.0f);
-    return npos;
+    if (pos_max > pos_min && pos >= pos_min && pos <= pos_max)
+        return (pos - pos_min) / (pos_max - pos_min);
+    else
+        return 0.0f;
 }
 
 void player::reset_playstate()
@@ -546,36 +549,44 @@ void player::set_pos(float pos)
 
 int player::set_video_stream(int s)
 {
-    if (s < 0 || s >= global_dispatch->get_media_input()->video_streams())
-        s = 0;
+    assert(dispatch::media_input())
+    assert(s >= 0 && s < dispatch::media_input()->video_streams());
     global_dispatch->get_media_input()->select_video_stream(s);
-    _seek_request = -1; // Get position right
+    if (dispatch::playing())
+        _seek_request = -1; // Get position right
     return s;
 }
 
 int player::set_audio_stream(int s)
 {
-    if (s < 0 || s >= global_dispatch->get_media_input()->audio_streams())
-        s = 0;
+    assert(dispatch::media_input())
+    assert(s >= 0 && s < dispatch::media_input()->audio_streams());
     global_dispatch->get_media_input()->select_audio_stream(s);
-    _seek_request = -1; // Get position right
+    if (dispatch::playing())
+        _seek_request = -1; // Get position right
     return s;
 }
 
 int player::set_subtitle_stream(int s)
 {
-    if (s < -1 || s >= global_dispatch->get_media_input()->subtitle_streams())
-        s = -1;
+    assert(dispatch::media_input())
+    assert(s >= -1 && s < dispatch::media_input()->subtitle_streams());
     global_dispatch->get_media_input()->select_subtitle_stream(s);
-    _seek_request = -1; // Get position right
+    if (dispatch::playing())
+        _seek_request = -1; // Get position right
     return s;
 }
 
 void player::set_stereo_layout(parameters::stereo_layout_t stereo_layout)
 {
     global_dispatch->get_media_input()->set_stereo_layout(stereo_layout, dispatch::parameters().stereo_layout_swap());
-    if (stereo_layout == parameters::layout_separate)
-        _seek_request = -1;     // Get position of both streams right
+    // If the new layout is layout_separate, then seek to synchronize both video streams.
+    // If we're pausing, then seek to reload the current frame (or a near frame) and
+    // trigger an update of the display.
+    // In other cases, we can just continue to read our video and the display will
+    // update with the next frame.
+    if (stereo_layout == parameters::layout_separate || dispatch::pausing())
+        _seek_request = -1;
 }
 
 void player::set_stereo_layout_swap(bool swap)
