@@ -104,7 +104,7 @@ void gl_thread::activate_next_frame()
     _wait_mutex.lock();
     _action_finished = false;
     _action_activate = true;
-    while(_action_activate)
+    while (_action_activate)
         _wait_cond.wait(_wait_mutex);
     _action_finished = true;
     _wait_mutex.unlock();
@@ -119,7 +119,7 @@ void gl_thread::prepare_next_frame(const video_frame &frame, const subtitle_box
     _next_frame = frame;
     _action_finished = false;
     _action_prepare = true;
-    while(_action_prepare)
+    while (_action_prepare)
         _wait_cond.wait(_wait_mutex);
     _action_finished = true;
     _wait_mutex.unlock();
@@ -209,7 +209,20 @@ void gl_thread::run()
                 _vo_qt->sdi_output(_display_frameno);
 #endif // HAVE_LIBXNVCTRL
                 _vo_qt->display_current_frame(_display_frameno);
+                // Swap buffers. To avoid problems with the NVIDIA 304.x driver
+                // series on GNU/Linux, we first release the GL context and re-grab
+                // it after the swap. Not sure why that would be necessary, but it
+                // fixes a problem where swapBuffers() does not return and the
+                // application blocks.
+                // However, this breaks video playback on Windows, so only do it on
+                // X11 systems.
+#ifdef Q_WS_X11
+                _vo_qt_widget->doneCurrent();
+#endif
                 _vo_qt_widget->swapBuffers();
+#ifdef Q_WS_X11
+                _vo_qt_widget->makeCurrent();
+#endif
             } else if (!dispatch::parameters().benchmark()) {
                 // do not busy loop
                 usleep(1000);
@@ -227,7 +240,7 @@ void gl_thread::run()
             _wait_cond.wake_one();
             _wait_mutex.unlock();
             _wait_mutex.lock();
-     }
+        }
     }
     _wait_mutex.unlock();
     _vo_qt_widget->doneCurrent();
